@@ -5,7 +5,7 @@ use warnings;
 use Scalar::Util qw{reftype blessed};
 use XML::LibXML::LazyBuilder qw{E};
 
-our $VERSION='0.10';
+our $VERSION='0.12';
 
 =head1 NAME
 
@@ -92,6 +92,7 @@ sub node {
   my $self=shift;
   my @element=();
   push @element, E(name=>{}, $self->name) if defined $self->name;
+  push @element, E(Snippet=>{maxLines=>scalar(@{$self->Snippet})}, join("\n", @{$self->Snippet}));
   push @element, E(description=>{}, $self->description)
     if defined $self->description;
   push @element, E(visibility=>{}, $self->visibility)
@@ -202,7 +203,7 @@ Please log on RT and send to the geo-perl email list.
 
 =head1 SUPPORT
 
-Try geo-perl email list.
+DavisNetworks.com supports all Perl applications including this package.
 
 =head1 AUTHOR
 
@@ -215,8 +216,7 @@ This program is free software licensed under the...
 
   The BSD License
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+The full text of the license can be found in the LICENSE file included with this module.
 
 =head1 SEE ALSO
 
